@@ -620,7 +620,7 @@ def mmlhs(X_start: np.ndarray, population: int, iterations: int, q: Optional[flo
     return X_best
 
 
-def bestlh(n: int, k: int, population: int, iterations: int, p=1, plot=False, verbosity=0) -> np.ndarray:
+def bestlh(n: int, k: int, population: int, iterations: int, p=1, plot=False, verbosity=0, edges=0) -> np.ndarray:
     """
     Generates an optimized Latin hypercube by evolving the Morris-Mitchell
     criterion across multiple exponents (q values) and selecting the best plan.
@@ -642,6 +642,10 @@ def bestlh(n: int, k: int, population: int, iterations: int, p=1, plot=False, ve
             will be displayed. Only if k>=2.  Defaults to False.
         verbosity (int, optional):
             Verbosity level. 0 is silent, 1 prints the best q value found. Defaults to 0.
+        edges (int, optional):
+            If 1, places centers of the extreme bins at the domain edges ([0,1]).
+            Otherwise, bins are fully contained within the domain, i.e. midpoints.
+            Defaults to 0.
 
     Returns:
         np.ndarray:
@@ -675,7 +679,7 @@ def bestlh(n: int, k: int, population: int, iterations: int, p=1, plot=False, ve
     q_list = [1, 2, 5, 10, 20, 50, 100]
 
     # Start with a random Latin hypercube
-    X_start = rlh(n, k, edges=1)
+    X_start = rlh(n, k, edges=edges)
 
     # Allocate a 3D array to store the results for each q
     # (shape: (n, k, number_of_q_values))
